/**********************************************************************\
**
**                         Copyright (c) 2009-2017 by
**                          HENSGSTLER GmbH, Aldingen
**
**      This  software  is furnished under a licence and may be used and
**      copied only in accordance with the terms  of  such  licence  and
**      with the inclusion of the above copyright notice.  This software
**      or any other copies thereof may not  be  provided  or  otherwise
**      made  available  to any other person.  No title to and ownership
**      of the software is hereby transferred.
**
**      The  information  in  this software is subject to change without
**      notice and should not be construed as a commitment by Hengstler.
**
**  Module:      Exo_Api.h
**  Facility:    Hengstler Extendo Linux Printer Driver Package / S684018
**  Application: Extendo application programming interface (API) for linux (libExoApi)
**  Version:     R3-V1_03a-BETA-2017FEB13
**  Environment: Linux Debian
**  Compiler:    gcc
**  Authors:     L. Tkac
**  Abstract:    Api Library header file
**  History:     R2-V1.01  / 2009JUN16 / TKA / Initial version
**               R3-V1.02a / 2011DEC14 / TKA / TKA-COR-03-New API communication added (libusb)
**
\**********************************************************************/

#ifndef __EXO_API_H
#define __EXO_API_H

/*
** INCLUDES
*/

#ifdef __cplusplus
extern "C" {
#endif

/*
** MACROS
*/

//-- Error codes of application programming interface
#define D_EXO_API_OPEN_FAILED       -1
#define D_EXO_API_INVALID_DEVICE    -2
#define D_EXO_API_DETACH_FAILED     -3
#define D_EXO_API_CLAIM_FAILED      -4

/*
** TYPES
*/


/*
** VARIABLES
*/

/*
** FUNCTIONS
*/

//-- Inquiry function 
char *         exo_api_get_library_info    (void);

//-- Printer communication interface
int            exo_api_printer_open        (char * port); // e.g. port = "/dev/usb/lp0" or port = "/dev/bus/usb/003/002"
int            exo_api_printer_set_serial  (int printer, unsigned long baud_rate, unsigned char data_bits, unsigned char parity, unsigned char stop_bits);
void           exo_api_printer_close       (int printer);
int            exo_api_printer_write       (int printer, unsigned char * data, int size, unsigned long timeout_ms);
int            exo_api_printer_read        (int printer, unsigned char * data, int size, unsigned long timeout_ms);
int            exo_api_printer_clear       (int printer);

#ifdef __cplusplus
}
#endif

#endif // __EXO_API_H







